<a id="mypy-boto3-connect"></a>

# mypy-boto3-connect

[![PyPI - mypy-boto3-connect](https://img.shields.io/pypi/v/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-connect.svg?color=blue)](https://pypi.org/project/mypy-boto3-connect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-connect?color=blue)](https://pypistats.org/packages/mypy-boto3-connect)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Connect 1.26.6](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/connect.html#Connect)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.10](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-connect docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connect/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-connect](#mypy-boto3-connect)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Connect`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `Connect` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[connect]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[connect]'


# standalone installation
python -m pip install mypy-boto3-connect
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-connect
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[connect]` in your environment:

```bash
python -m pip install 'boto3-stubs[connect]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[connect]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[connect]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[connect]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[connect]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[connect]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[connect]` in your environment:

```bash
python -m pip install 'boto3-stubs[connect]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[connect]` in your environment:

```bash
python -m pip install 'boto3-stubs[connect]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ConnectClient` provides annotations for `boto3.client("connect")`.

```python
from boto3.session import Session

from mypy_boto3_connect import ConnectClient

client: ConnectClient = Session().client("connect")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_connect.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_connect import ConnectClient
from mypy_boto3_connect.paginator import (
    GetMetricDataPaginator,
    ListAgentStatusesPaginator,
    ListApprovedOriginsPaginator,
    ListBotsPaginator,
    ListContactFlowModulesPaginator,
    ListContactFlowsPaginator,
    ListContactReferencesPaginator,
    ListDefaultVocabulariesPaginator,
    ListHoursOfOperationsPaginator,
    ListInstanceAttributesPaginator,
    ListInstanceStorageConfigsPaginator,
    ListInstancesPaginator,
    ListIntegrationAssociationsPaginator,
    ListLambdaFunctionsPaginator,
    ListLexBotsPaginator,
    ListPhoneNumbersPaginator,
    ListPhoneNumbersV2Paginator,
    ListPromptsPaginator,
    ListQueueQuickConnectsPaginator,
    ListQueuesPaginator,
    ListQuickConnectsPaginator,
    ListRoutingProfileQueuesPaginator,
    ListRoutingProfilesPaginator,
    ListSecurityKeysPaginator,
    ListSecurityProfilePermissionsPaginator,
    ListSecurityProfilesPaginator,
    ListTaskTemplatesPaginator,
    ListTrafficDistributionGroupsPaginator,
    ListUseCasesPaginator,
    ListUserHierarchyGroupsPaginator,
    ListUsersPaginator,
    SearchAvailablePhoneNumbersPaginator,
    SearchQueuesPaginator,
    SearchRoutingProfilesPaginator,
    SearchSecurityProfilesPaginator,
    SearchUsersPaginator,
    SearchVocabulariesPaginator,
)

client: ConnectClient = Session().client("connect")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
get_metric_data_paginator: GetMetricDataPaginator = client.get_paginator("get_metric_data")
list_agent_statuses_paginator: ListAgentStatusesPaginator = client.get_paginator(
    "list_agent_statuses"
)
list_approved_origins_paginator: ListApprovedOriginsPaginator = client.get_paginator(
    "list_approved_origins"
)
list_bots_paginator: ListBotsPaginator = client.get_paginator("list_bots")
list_contact_flow_modules_paginator: ListContactFlowModulesPaginator = client.get_paginator(
    "list_contact_flow_modules"
)
list_contact_flows_paginator: ListContactFlowsPaginator = client.get_paginator("list_contact_flows")
list_contact_references_paginator: ListContactReferencesPaginator = client.get_paginator(
    "list_contact_references"
)
list_default_vocabularies_paginator: ListDefaultVocabulariesPaginator = client.get_paginator(
    "list_default_vocabularies"
)
list_hours_of_operations_paginator: ListHoursOfOperationsPaginator = client.get_paginator(
    "list_hours_of_operations"
)
list_instance_attributes_paginator: ListInstanceAttributesPaginator = client.get_paginator(
    "list_instance_attributes"
)
list_instance_storage_configs_paginator: ListInstanceStorageConfigsPaginator = client.get_paginator(
    "list_instance_storage_configs"
)
list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
list_integration_associations_paginator: ListIntegrationAssociationsPaginator = (
    client.get_paginator("list_integration_associations")
)
list_lambda_functions_paginator: ListLambdaFunctionsPaginator = client.get_paginator(
    "list_lambda_functions"
)
list_lex_bots_paginator: ListLexBotsPaginator = client.get_paginator("list_lex_bots")
list_phone_numbers_paginator: ListPhoneNumbersPaginator = client.get_paginator("list_phone_numbers")
list_phone_numbers_v2_paginator: ListPhoneNumbersV2Paginator = client.get_paginator(
    "list_phone_numbers_v2"
)
list_prompts_paginator: ListPromptsPaginator = client.get_paginator("list_prompts")
list_queue_quick_connects_paginator: ListQueueQuickConnectsPaginator = client.get_paginator(
    "list_queue_quick_connects"
)
list_queues_paginator: ListQueuesPaginator = client.get_paginator("list_queues")
list_quick_connects_paginator: ListQuickConnectsPaginator = client.get_paginator(
    "list_quick_connects"
)
list_routing_profile_queues_paginator: ListRoutingProfileQueuesPaginator = client.get_paginator(
    "list_routing_profile_queues"
)
list_routing_profiles_paginator: ListRoutingProfilesPaginator = client.get_paginator(
    "list_routing_profiles"
)
list_security_keys_paginator: ListSecurityKeysPaginator = client.get_paginator("list_security_keys")
list_security_profile_permissions_paginator: ListSecurityProfilePermissionsPaginator = (
    client.get_paginator("list_security_profile_permissions")
)
list_security_profiles_paginator: ListSecurityProfilesPaginator = client.get_paginator(
    "list_security_profiles"
)
list_task_templates_paginator: ListTaskTemplatesPaginator = client.get_paginator(
    "list_task_templates"
)
list_traffic_distribution_groups_paginator: ListTrafficDistributionGroupsPaginator = (
    client.get_paginator("list_traffic_distribution_groups")
)
list_use_cases_paginator: ListUseCasesPaginator = client.get_paginator("list_use_cases")
list_user_hierarchy_groups_paginator: ListUserHierarchyGroupsPaginator = client.get_paginator(
    "list_user_hierarchy_groups"
)
list_users_paginator: ListUsersPaginator = client.get_paginator("list_users")
search_available_phone_numbers_paginator: SearchAvailablePhoneNumbersPaginator = (
    client.get_paginator("search_available_phone_numbers")
)
search_queues_paginator: SearchQueuesPaginator = client.get_paginator("search_queues")
search_routing_profiles_paginator: SearchRoutingProfilesPaginator = client.get_paginator(
    "search_routing_profiles"
)
search_security_profiles_paginator: SearchSecurityProfilesPaginator = client.get_paginator(
    "search_security_profiles"
)
search_users_paginator: SearchUsersPaginator = client.get_paginator("search_users")
search_vocabularies_paginator: SearchVocabulariesPaginator = client.get_paginator(
    "search_vocabularies"
)
```

<a id="literals"></a>

### Literals

`mypy_boto3_connect.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_connect.literals import (
    AgentStatusStateType,
    AgentStatusTypeType,
    ChannelType,
    ComparisonType,
    ContactFlowModuleStateType,
    ContactFlowModuleStatusType,
    ContactFlowStateType,
    ContactFlowTypeType,
    ContactInitiationMethodType,
    ContactStateType,
    CurrentMetricNameType,
    DirectoryTypeType,
    EncryptionTypeType,
    GetMetricDataPaginatorName,
    GroupingType,
    HierarchyGroupMatchTypeType,
    HistoricalMetricNameType,
    HoursOfOperationDaysType,
    InstanceAttributeTypeType,
    InstanceStatusType,
    InstanceStorageResourceTypeType,
    IntegrationTypeType,
    LexVersionType,
    ListAgentStatusesPaginatorName,
    ListApprovedOriginsPaginatorName,
    ListBotsPaginatorName,
    ListContactFlowModulesPaginatorName,
    ListContactFlowsPaginatorName,
    ListContactReferencesPaginatorName,
    ListDefaultVocabulariesPaginatorName,
    ListHoursOfOperationsPaginatorName,
    ListInstanceAttributesPaginatorName,
    ListInstanceStorageConfigsPaginatorName,
    ListInstancesPaginatorName,
    ListIntegrationAssociationsPaginatorName,
    ListLambdaFunctionsPaginatorName,
    ListLexBotsPaginatorName,
    ListPhoneNumbersPaginatorName,
    ListPhoneNumbersV2PaginatorName,
    ListPromptsPaginatorName,
    ListQueueQuickConnectsPaginatorName,
    ListQueuesPaginatorName,
    ListQuickConnectsPaginatorName,
    ListRoutingProfileQueuesPaginatorName,
    ListRoutingProfilesPaginatorName,
    ListSecurityKeysPaginatorName,
    ListSecurityProfilePermissionsPaginatorName,
    ListSecurityProfilesPaginatorName,
    ListTaskTemplatesPaginatorName,
    ListTrafficDistributionGroupsPaginatorName,
    ListUseCasesPaginatorName,
    ListUserHierarchyGroupsPaginatorName,
    ListUsersPaginatorName,
    PhoneNumberCountryCodeType,
    PhoneNumberTypeType,
    PhoneNumberWorkflowStatusType,
    PhoneTypeType,
    QueueStatusType,
    QueueTypeType,
    QuickConnectTypeType,
    ReferenceStatusType,
    ReferenceTypeType,
    SearchAvailablePhoneNumbersPaginatorName,
    SearchQueuesPaginatorName,
    SearchRoutingProfilesPaginatorName,
    SearchSecurityProfilesPaginatorName,
    SearchUsersPaginatorName,
    SearchVocabulariesPaginatorName,
    SearchableQueueTypeType,
    SourceTypeType,
    StatisticType,
    StorageTypeType,
    StringComparisonTypeType,
    TaskTemplateFieldTypeType,
    TaskTemplateStatusType,
    TrafficDistributionGroupStatusType,
    TrafficTypeType,
    UnitType,
    UseCaseTypeType,
    VocabularyLanguageCodeType,
    VocabularyStateType,
    VoiceRecordingTrackType,
    ConnectServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AgentStatusStateType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_connect.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_connect.type_defs import (
    QueueReferenceTypeDef,
    AgentInfoTypeDef,
    AgentStatusReferenceTypeDef,
    AgentStatusSummaryTypeDef,
    AgentStatusTypeDef,
    AnswerMachineDetectionConfigTypeDef,
    AssociateApprovedOriginRequestRequestTypeDef,
    LexBotTypeDef,
    LexV2BotTypeDef,
    AssociateDefaultVocabularyRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    AssociateLambdaFunctionRequestRequestTypeDef,
    AssociatePhoneNumberContactFlowRequestRequestTypeDef,
    AssociateQueueQuickConnectsRequestRequestTypeDef,
    AssociateSecurityKeyRequestRequestTypeDef,
    AttachmentReferenceTypeDef,
    AttributeTypeDef,
    AvailableNumberSummaryTypeDef,
    ChatMessageTypeDef,
    ChatStreamingConfigurationTypeDef,
    ClaimPhoneNumberRequestRequestTypeDef,
    PhoneNumberStatusTypeDef,
    ContactFilterTypeDef,
    ContactFlowModuleSummaryTypeDef,
    ContactFlowModuleTypeDef,
    ContactFlowSummaryTypeDef,
    ContactFlowTypeDef,
    QueueInfoTypeDef,
    TagConditionTypeDef,
    CreateAgentStatusRequestRequestTypeDef,
    CreateContactFlowModuleRequestRequestTypeDef,
    CreateContactFlowRequestRequestTypeDef,
    CreateInstanceRequestRequestTypeDef,
    CreateIntegrationAssociationRequestRequestTypeDef,
    OutboundCallerConfigTypeDef,
    MediaConcurrencyTypeDef,
    CreateSecurityProfileRequestRequestTypeDef,
    CreateTrafficDistributionGroupRequestRequestTypeDef,
    CreateUseCaseRequestRequestTypeDef,
    CreateUserHierarchyGroupRequestRequestTypeDef,
    UserIdentityInfoTypeDef,
    UserPhoneConfigTypeDef,
    CreateVocabularyRequestRequestTypeDef,
    CredentialsTypeDef,
    CurrentMetricTypeDef,
    DateReferenceTypeDef,
    DefaultVocabularyTypeDef,
    DeleteContactFlowModuleRequestRequestTypeDef,
    DeleteContactFlowRequestRequestTypeDef,
    DeleteHoursOfOperationRequestRequestTypeDef,
    DeleteInstanceRequestRequestTypeDef,
    DeleteIntegrationAssociationRequestRequestTypeDef,
    DeleteQuickConnectRequestRequestTypeDef,
    DeleteSecurityProfileRequestRequestTypeDef,
    DeleteTaskTemplateRequestRequestTypeDef,
    DeleteTrafficDistributionGroupRequestRequestTypeDef,
    DeleteUseCaseRequestRequestTypeDef,
    DeleteUserHierarchyGroupRequestRequestTypeDef,
    DeleteUserRequestRequestTypeDef,
    DeleteVocabularyRequestRequestTypeDef,
    DescribeAgentStatusRequestRequestTypeDef,
    DescribeContactFlowModuleRequestRequestTypeDef,
    DescribeContactFlowRequestRequestTypeDef,
    DescribeContactRequestRequestTypeDef,
    DescribeHoursOfOperationRequestRequestTypeDef,
    DescribeInstanceAttributeRequestRequestTypeDef,
    DescribeInstanceRequestRequestTypeDef,
    DescribeInstanceStorageConfigRequestRequestTypeDef,
    DescribePhoneNumberRequestRequestTypeDef,
    DescribeQueueRequestRequestTypeDef,
    DescribeQuickConnectRequestRequestTypeDef,
    DescribeRoutingProfileRequestRequestTypeDef,
    DescribeSecurityProfileRequestRequestTypeDef,
    SecurityProfileTypeDef,
    DescribeTrafficDistributionGroupRequestRequestTypeDef,
    TrafficDistributionGroupTypeDef,
    DescribeUserHierarchyGroupRequestRequestTypeDef,
    DescribeUserHierarchyStructureRequestRequestTypeDef,
    DescribeUserRequestRequestTypeDef,
    DescribeVocabularyRequestRequestTypeDef,
    VocabularyTypeDef,
    DisassociateApprovedOriginRequestRequestTypeDef,
    DisassociateInstanceStorageConfigRequestRequestTypeDef,
    DisassociateLambdaFunctionRequestRequestTypeDef,
    DisassociateLexBotRequestRequestTypeDef,
    DisassociatePhoneNumberContactFlowRequestRequestTypeDef,
    DisassociateQueueQuickConnectsRequestRequestTypeDef,
    RoutingProfileQueueReferenceTypeDef,
    DisassociateSecurityKeyRequestRequestTypeDef,
    DismissUserContactRequestRequestTypeDef,
    DistributionTypeDef,
    EmailReferenceTypeDef,
    EncryptionConfigTypeDef,
    FiltersTypeDef,
    GetContactAttributesRequestRequestTypeDef,
    GetFederationTokenRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    GetTaskTemplateRequestRequestTypeDef,
    GetTrafficDistributionRequestRequestTypeDef,
    HierarchyGroupConditionTypeDef,
    HierarchyGroupSummaryReferenceTypeDef,
    HierarchyGroupSummaryTypeDef,
    HierarchyLevelTypeDef,
    HierarchyLevelUpdateTypeDef,
    ThresholdTypeDef,
    HoursOfOperationTimeSliceTypeDef,
    HoursOfOperationSummaryTypeDef,
    InstanceStatusReasonTypeDef,
    KinesisFirehoseConfigTypeDef,
    KinesisStreamConfigTypeDef,
    InstanceSummaryTypeDef,
    IntegrationAssociationSummaryTypeDef,
    TaskTemplateFieldIdentifierTypeDef,
    ListAgentStatusRequestRequestTypeDef,
    ListApprovedOriginsRequestRequestTypeDef,
    ListBotsRequestRequestTypeDef,
    ListContactFlowModulesRequestRequestTypeDef,
    ListContactFlowsRequestRequestTypeDef,
    ListContactReferencesRequestRequestTypeDef,
    ListDefaultVocabulariesRequestRequestTypeDef,
    ListHoursOfOperationsRequestRequestTypeDef,
    ListInstanceAttributesRequestRequestTypeDef,
    ListInstanceStorageConfigsRequestRequestTypeDef,
    ListInstancesRequestRequestTypeDef,
    ListIntegrationAssociationsRequestRequestTypeDef,
    ListLambdaFunctionsRequestRequestTypeDef,
    ListLexBotsRequestRequestTypeDef,
    ListPhoneNumbersRequestRequestTypeDef,
    PhoneNumberSummaryTypeDef,
    ListPhoneNumbersSummaryTypeDef,
    ListPhoneNumbersV2RequestRequestTypeDef,
    ListPromptsRequestRequestTypeDef,
    PromptSummaryTypeDef,
    ListQueueQuickConnectsRequestRequestTypeDef,
    QuickConnectSummaryTypeDef,
    ListQueuesRequestRequestTypeDef,
    QueueSummaryTypeDef,
    ListQuickConnectsRequestRequestTypeDef,
    ListRoutingProfileQueuesRequestRequestTypeDef,
    RoutingProfileQueueConfigSummaryTypeDef,
    ListRoutingProfilesRequestRequestTypeDef,
    RoutingProfileSummaryTypeDef,
    ListSecurityKeysRequestRequestTypeDef,
    SecurityKeyTypeDef,
    ListSecurityProfilePermissionsRequestRequestTypeDef,
    ListSecurityProfilesRequestRequestTypeDef,
    SecurityProfileSummaryTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTaskTemplatesRequestRequestTypeDef,
    TaskTemplateMetadataTypeDef,
    ListTrafficDistributionGroupsRequestRequestTypeDef,
    TrafficDistributionGroupSummaryTypeDef,
    ListUseCasesRequestRequestTypeDef,
    UseCaseTypeDef,
    ListUserHierarchyGroupsRequestRequestTypeDef,
    ListUsersRequestRequestTypeDef,
    UserSummaryTypeDef,
    NumberReferenceTypeDef,
    ParticipantDetailsTypeDef,
    PhoneNumberQuickConnectConfigTypeDef,
    PutUserStatusRequestRequestTypeDef,
    QueueQuickConnectConfigTypeDef,
    StringConditionTypeDef,
    UserQuickConnectConfigTypeDef,
    StringReferenceTypeDef,
    UrlReferenceTypeDef,
    ReferenceTypeDef,
    ReleasePhoneNumberRequestRequestTypeDef,
    ReplicateInstanceRequestRequestTypeDef,
    ResumeContactRecordingRequestRequestTypeDef,
    RoutingProfileReferenceTypeDef,
    SearchAvailablePhoneNumbersRequestRequestTypeDef,
    SecurityProfileSearchSummaryTypeDef,
    SearchVocabulariesRequestRequestTypeDef,
    VocabularySummaryTypeDef,
    VoiceRecordingConfigurationTypeDef,
    StopContactRecordingRequestRequestTypeDef,
    StopContactRequestRequestTypeDef,
    StopContactStreamingRequestRequestTypeDef,
    SuspendContactRecordingRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    TransferContactRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAgentStatusRequestRequestTypeDef,
    UpdateContactAttributesRequestRequestTypeDef,
    UpdateContactFlowContentRequestRequestTypeDef,
    UpdateContactFlowMetadataRequestRequestTypeDef,
    UpdateContactFlowModuleContentRequestRequestTypeDef,
    UpdateContactFlowModuleMetadataRequestRequestTypeDef,
    UpdateContactFlowNameRequestRequestTypeDef,
    UpdateContactScheduleRequestRequestTypeDef,
    UpdateInstanceAttributeRequestRequestTypeDef,
    UpdatePhoneNumberRequestRequestTypeDef,
    UpdateQueueHoursOfOperationRequestRequestTypeDef,
    UpdateQueueMaxContactsRequestRequestTypeDef,
    UpdateQueueNameRequestRequestTypeDef,
    UpdateQueueStatusRequestRequestTypeDef,
    UpdateQuickConnectNameRequestRequestTypeDef,
    UpdateRoutingProfileDefaultOutboundQueueRequestRequestTypeDef,
    UpdateRoutingProfileNameRequestRequestTypeDef,
    UpdateSecurityProfileRequestRequestTypeDef,
    UpdateUserHierarchyGroupNameRequestRequestTypeDef,
    UpdateUserHierarchyRequestRequestTypeDef,
    UpdateUserRoutingProfileRequestRequestTypeDef,
    UpdateUserSecurityProfilesRequestRequestTypeDef,
    UserReferenceTypeDef,
    UserIdentityInfoLiteTypeDef,
    AgentContactReferenceTypeDef,
    DimensionsTypeDef,
    StartOutboundVoiceContactRequestRequestTypeDef,
    AssociateLexBotRequestRequestTypeDef,
    AssociateBotRequestRequestTypeDef,
    DisassociateBotRequestRequestTypeDef,
    LexBotConfigTypeDef,
    AssociateInstanceStorageConfigResponseTypeDef,
    AssociateSecurityKeyResponseTypeDef,
    ClaimPhoneNumberResponseTypeDef,
    CreateAgentStatusResponseTypeDef,
    CreateContactFlowModuleResponseTypeDef,
    CreateContactFlowResponseTypeDef,
    CreateHoursOfOperationResponseTypeDef,
    CreateInstanceResponseTypeDef,
    CreateIntegrationAssociationResponseTypeDef,
    CreateQueueResponseTypeDef,
    CreateQuickConnectResponseTypeDef,
    CreateRoutingProfileResponseTypeDef,
    CreateSecurityProfileResponseTypeDef,
    CreateTaskTemplateResponseTypeDef,
    CreateTrafficDistributionGroupResponseTypeDef,
    CreateUseCaseResponseTypeDef,
    CreateUserHierarchyGroupResponseTypeDef,
    CreateUserResponseTypeDef,
    CreateVocabularyResponseTypeDef,
    DeleteVocabularyResponseTypeDef,
    DescribeAgentStatusResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetContactAttributesResponseTypeDef,
    ListAgentStatusResponseTypeDef,
    ListApprovedOriginsResponseTypeDef,
    ListLambdaFunctionsResponseTypeDef,
    ListLexBotsResponseTypeDef,
    ListSecurityProfilePermissionsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ReplicateInstanceResponseTypeDef,
    StartChatContactResponseTypeDef,
    StartContactStreamingResponseTypeDef,
    StartOutboundVoiceContactResponseTypeDef,
    StartTaskContactResponseTypeDef,
    TransferContactResponseTypeDef,
    UpdatePhoneNumberResponseTypeDef,
    DescribeInstanceAttributeResponseTypeDef,
    ListInstanceAttributesResponseTypeDef,
    SearchAvailablePhoneNumbersResponseTypeDef,
    StartContactStreamingRequestRequestTypeDef,
    ClaimedPhoneNumberSummaryTypeDef,
    UserDataFiltersTypeDef,
    ListContactFlowModulesResponseTypeDef,
    DescribeContactFlowModuleResponseTypeDef,
    ListContactFlowsResponseTypeDef,
    DescribeContactFlowResponseTypeDef,
    ContactTypeDef,
    ControlPlaneTagFilterTypeDef,
    CreateQueueRequestRequestTypeDef,
    QueueTypeDef,
    UpdateQueueOutboundCallerConfigRequestRequestTypeDef,
    RoutingProfileTypeDef,
    UpdateRoutingProfileConcurrencyRequestRequestTypeDef,
    UpdateUserIdentityInfoRequestRequestTypeDef,
    CreateUserRequestRequestTypeDef,
    UpdateUserPhoneConfigRequestRequestTypeDef,
    UserTypeDef,
    GetFederationTokenResponseTypeDef,
    CurrentMetricDataTypeDef,
    ListDefaultVocabulariesResponseTypeDef,
    DescribeSecurityProfileResponseTypeDef,
    DescribeTrafficDistributionGroupResponseTypeDef,
    DescribeVocabularyResponseTypeDef,
    DisassociateRoutingProfileQueuesRequestRequestTypeDef,
    RoutingProfileQueueConfigTypeDef,
    TelephonyConfigTypeDef,
    KinesisVideoStreamConfigTypeDef,
    S3ConfigTypeDef,
    GetCurrentMetricDataRequestRequestTypeDef,
    ListAgentStatusRequestListAgentStatusesPaginateTypeDef,
    ListApprovedOriginsRequestListApprovedOriginsPaginateTypeDef,
    ListBotsRequestListBotsPaginateTypeDef,
    ListContactFlowModulesRequestListContactFlowModulesPaginateTypeDef,
    ListContactFlowsRequestListContactFlowsPaginateTypeDef,
    ListContactReferencesRequestListContactReferencesPaginateTypeDef,
    ListDefaultVocabulariesRequestListDefaultVocabulariesPaginateTypeDef,
    ListHoursOfOperationsRequestListHoursOfOperationsPaginateTypeDef,
    ListInstanceAttributesRequestListInstanceAttributesPaginateTypeDef,
    ListInstanceStorageConfigsRequestListInstanceStorageConfigsPaginateTypeDef,
    ListInstancesRequestListInstancesPaginateTypeDef,
    ListIntegrationAssociationsRequestListIntegrationAssociationsPaginateTypeDef,
    ListLambdaFunctionsRequestListLambdaFunctionsPaginateTypeDef,
    ListLexBotsRequestListLexBotsPaginateTypeDef,
    ListPhoneNumbersRequestListPhoneNumbersPaginateTypeDef,
    ListPhoneNumbersV2RequestListPhoneNumbersV2PaginateTypeDef,
    ListPromptsRequestListPromptsPaginateTypeDef,
    ListQueueQuickConnectsRequestListQueueQuickConnectsPaginateTypeDef,
    ListQueuesRequestListQueuesPaginateTypeDef,
    ListQuickConnectsRequestListQuickConnectsPaginateTypeDef,
    ListRoutingProfileQueuesRequestListRoutingProfileQueuesPaginateTypeDef,
    ListRoutingProfilesRequestListRoutingProfilesPaginateTypeDef,
    ListSecurityKeysRequestListSecurityKeysPaginateTypeDef,
    ListSecurityProfilePermissionsRequestListSecurityProfilePermissionsPaginateTypeDef,
    ListSecurityProfilesRequestListSecurityProfilesPaginateTypeDef,
    ListTaskTemplatesRequestListTaskTemplatesPaginateTypeDef,
    ListTrafficDistributionGroupsRequestListTrafficDistributionGroupsPaginateTypeDef,
    ListUseCasesRequestListUseCasesPaginateTypeDef,
    ListUserHierarchyGroupsRequestListUserHierarchyGroupsPaginateTypeDef,
    ListUsersRequestListUsersPaginateTypeDef,
    SearchAvailablePhoneNumbersRequestSearchAvailablePhoneNumbersPaginateTypeDef,
    SearchVocabulariesRequestSearchVocabulariesPaginateTypeDef,
    HierarchyPathReferenceTypeDef,
    HierarchyPathTypeDef,
    ListUserHierarchyGroupsResponseTypeDef,
    HierarchyStructureTypeDef,
    HierarchyStructureUpdateTypeDef,
    HistoricalMetricTypeDef,
    HoursOfOperationConfigTypeDef,
    ListHoursOfOperationsResponseTypeDef,
    InstanceTypeDef,
    ListInstancesResponseTypeDef,
    ListIntegrationAssociationsResponseTypeDef,
    InvisibleFieldInfoTypeDef,
    ReadOnlyFieldInfoTypeDef,
    RequiredFieldInfoTypeDef,
    TaskTemplateDefaultFieldValueTypeDef,
    TaskTemplateFieldTypeDef,
    ListPhoneNumbersResponseTypeDef,
    ListPhoneNumbersV2ResponseTypeDef,
    ListPromptsResponseTypeDef,
    ListQueueQuickConnectsResponseTypeDef,
    ListQuickConnectsResponseTypeDef,
    ListQueuesResponseTypeDef,
    ListRoutingProfileQueuesResponseTypeDef,
    ListRoutingProfilesResponseTypeDef,
    ListSecurityKeysResponseTypeDef,
    ListSecurityProfilesResponseTypeDef,
    ListTaskTemplatesResponseTypeDef,
    ListTrafficDistributionGroupsResponseTypeDef,
    ListUseCasesResponseTypeDef,
    ListUsersResponseTypeDef,
    StartChatContactRequestRequestTypeDef,
    QueueSearchCriteriaTypeDef,
    RoutingProfileSearchCriteriaTypeDef,
    SecurityProfileSearchCriteriaTypeDef,
    UserSearchCriteriaTypeDef,
    QuickConnectConfigTypeDef,
    ReferenceSummaryTypeDef,
    StartTaskContactRequestRequestTypeDef,
    UpdateContactRequestRequestTypeDef,
    SearchSecurityProfilesResponseTypeDef,
    SearchVocabulariesResponseTypeDef,
    StartContactRecordingRequestRequestTypeDef,
    UserSearchSummaryTypeDef,
    ListBotsResponseTypeDef,
    DescribePhoneNumberResponseTypeDef,
    GetCurrentUserDataRequestRequestTypeDef,
    DescribeContactResponseTypeDef,
    QueueSearchFilterTypeDef,
    RoutingProfileSearchFilterTypeDef,
    SecurityProfilesSearchFilterTypeDef,
    UserSearchFilterTypeDef,
    DescribeQueueResponseTypeDef,
    SearchQueuesResponseTypeDef,
    DescribeRoutingProfileResponseTypeDef,
    SearchRoutingProfilesResponseTypeDef,
    DescribeUserResponseTypeDef,
    CurrentMetricResultTypeDef,
    AssociateRoutingProfileQueuesRequestRequestTypeDef,
    CreateRoutingProfileRequestRequestTypeDef,
    UpdateRoutingProfileQueuesRequestRequestTypeDef,
    GetTrafficDistributionResponseTypeDef,
    UpdateTrafficDistributionRequestRequestTypeDef,
    InstanceStorageConfigTypeDef,
    UserDataTypeDef,
    HierarchyGroupTypeDef,
    DescribeUserHierarchyStructureResponseTypeDef,
    UpdateUserHierarchyStructureRequestRequestTypeDef,
    GetMetricDataRequestGetMetricDataPaginateTypeDef,
    GetMetricDataRequestRequestTypeDef,
    HistoricalMetricDataTypeDef,
    CreateHoursOfOperationRequestRequestTypeDef,
    HoursOfOperationTypeDef,
    UpdateHoursOfOperationRequestRequestTypeDef,
    DescribeInstanceResponseTypeDef,
    TaskTemplateConstraintsTypeDef,
    TaskTemplateDefaultsTypeDef,
    CreateQuickConnectRequestRequestTypeDef,
    QuickConnectTypeDef,
    UpdateQuickConnectConfigRequestRequestTypeDef,
    ListContactReferencesResponseTypeDef,
    SearchUsersResponseTypeDef,
    SearchQueuesRequestRequestTypeDef,
    SearchQueuesRequestSearchQueuesPaginateTypeDef,
    SearchRoutingProfilesRequestRequestTypeDef,
    SearchRoutingProfilesRequestSearchRoutingProfilesPaginateTypeDef,
    SearchSecurityProfilesRequestRequestTypeDef,
    SearchSecurityProfilesRequestSearchSecurityProfilesPaginateTypeDef,
    SearchUsersRequestRequestTypeDef,
    SearchUsersRequestSearchUsersPaginateTypeDef,
    GetCurrentMetricDataResponseTypeDef,
    AssociateInstanceStorageConfigRequestRequestTypeDef,
    DescribeInstanceStorageConfigResponseTypeDef,
    ListInstanceStorageConfigsResponseTypeDef,
    UpdateInstanceStorageConfigRequestRequestTypeDef,
    GetCurrentUserDataResponseTypeDef,
    DescribeUserHierarchyGroupResponseTypeDef,
    HistoricalMetricResultTypeDef,
    DescribeHoursOfOperationResponseTypeDef,
    CreateTaskTemplateRequestRequestTypeDef,
    GetTaskTemplateResponseTypeDef,
    UpdateTaskTemplateRequestRequestTypeDef,
    UpdateTaskTemplateResponseTypeDef,
    DescribeQuickConnectResponseTypeDef,
    GetMetricDataResponseTypeDef,
)


def get_structure() -> QueueReferenceTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-connect` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_connect/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
